@@ -1,233 +1,16 @@
-"grf" <-
-  function(n, grid = "irreg",
-           nx = round(sqrt(n)), ny = round(sqrt(n)),
-           xlims = c(0, 1), ylims = c(0, 1), nsim = 1, 
-           cov.model = "matern",
-           cov.pars = stop("covariance parameters (sigmasq and phi) needed"),
-           kappa = 0.5,  nugget=0, lambda=1, aniso.pars = NULL,
-           method = c("cholesky", "svd", "eigen", "circular.embedding"),
-           messages.screen = TRUE)
+"locations.inside" <-
+  function(locations, borders)
 {
-  ##
-  ## reading and checking input
-  ##
-  call.fc <- match.call()
-  method <- match.arg(method)
-  if((method == "circular.embedding") & messages.screen)
-    cat("grf: for simulation of fiends with large number of points the consider the packages RandomFields should be considered.\n") 
-  cov.model <- match.arg(cov.model,
-                         choices = c("matern", "exponential", "gaussian",
-                           "spherical", "circular", "cubic", "wave", "power",
-                           "powered.exponential", "cauchy", "gneiting",
-                           "gneiting.matern", "pure.nugget"))
-  if(!is.null(kappa))
-    if(cov.model == "matern" & kappa == 0.5) cov.model <- "exponential"
-  rseed <- .Random.seed
-  tausq <- nugget
-  if (is.vector(cov.pars)) {
-    sigmasq <- cov.pars[1]
-    phi <- cov.pars[2]
-    nst <- 1
-  }
-  else {
-    sigmasq <- cov.pars[, 1]
-    phi <- cov.pars[, 2]
-    nst <- nrow(cov.pars)
-  }
-  sill.total <- tausq + sum(sigmasq)
-  messa <- grf.aux1(nst, nugget, sigmasq, phi, kappa, cov.model)
-  if (messages.screen) {
-    cat(messa$nst)
-    cat(messa$nugget)
-    cat(messa$cov.structures)
-    cat(paste("grf: decomposition algorithm used is: ", method, "\n"))
-  }
-  results <- list()
-  ##
-  ## defining the locations for the simulated data
-  ##
-  if (is.matrix(grid) | is.data.frame(grid)) {
-    results$coords <- as.matrix(grid)
-    if (messages.screen) 
-      cat("grf: simulation(s) on a grid provided by the user\n")
-  }
-  else {
-    if (grid == "irreg") {
-      results$coords <- cbind(x = runif(n, xlims[1], xlims[2]),
-                              y = runif(n, ylims[1], ylims[2]))
-      if (messages.screen) 
-        cat(paste("grf: simulation(s) on random locations with ", n, " points\n"))
-    }
-    else {
-      results$coords <- as.matrix(expand.grid(x = seq(xlims[1], xlims[2], l = nx),
-                                              y = seq(ylims[1], ylims[2], l = ny)))
-      if (messages.screen) 
-        cat(paste("grf: generating grid ", nx, " * ", ny, 
-                  " with ", (nx*ny), " points\n"))
-    }
-  }
-  n <- nrow(results$coords)
-  ##
-  ## transforming to the isotropic space 
-  ##
-  if(!is.null(aniso.pars)) {
-    if(method == "circular.embedding")
-      stop("anisotropic models not implemented for the circular embedding method. \nConsider using the package \"RandomFields")
-    if(length(aniso.pars) != 2 | !is.numeric(aniso.pars))
-      stop("anisotropy parameters must be provided as a numeric vector with two elements: the rotation angle (in radians) and the anisotropy ratio (a number greater than 1)")
-    if(messages.screen)
-      cat("grf: transforming to the isotropic space \n")
-    results$coords <- coords.aniso(coords = results$coords,
-                                   aniso.pars = aniso.pars)
-  }
-  ##
-  ## simulating data at locations defined by the matrix results$coords
-  ##
-  if (all(phi) == 0) {
-    results$data <- matrix(rnorm((n * nsim), mean = 0, sd = sqrt(sill.total)), 
-                           nrow = n, ncol = nsim)
-  }
-  else {
-    if (method == "circular.embedding") {
-      if (grid == "irreg") 
-        stop("Option for \"circular.embedding\" algorithm only allowed for regular grids. You might have to include the argument grid=\"reg\"")
-      stepx <- (xlims[2] - xlims[1])/(nx - 1)
-      stepy <- (ylims[2] - ylims[1])/(ny - 1)
-      if (round(1e+08 * stepx) != round(1e+08 *stepy)) 
-        stop("grf: distance between grid points must be the same in X and Y directions")
-      temp <- list(n = n, nst = nst, sigmasq = sigmasq, 
-                   xlims = xlims, ylims = ylims, stepx = stepx, 
-                   cov.model = cov.model, phi = phi, kappa = kappa)
-      if(messages.screen)
-        cat("\ngrf: WARNING:\nmessages of the type mtot=XXXXX will appear on your screen. \nIf there are many (3 or more, say) or they run indefinitely, you should stop the simulation and try again with a different grid (e.g. try to add 1 point in each direction)\n")
-      grf.aux3 <- function (nsim, temp) {
-        realiz <- rep(0, temp$n)
-        for (i in 1:temp$nst) {
-          realiz <- realiz + sqrt(temp$sigmasq[i]) *
-            grf.aux2(xlim = temp$xlims, 
-                     ylim = temp$ylims, step = temp$stepx,
-                     cov.model = temp$cov.model,
-                     phi = temp$phi[i], kappa = temp$kappa)
-          NULL
-        }
-        return(realiz)
-      }      
-      results$data <- apply(as.matrix(1:nsim), 1, grf.aux3, temp = temp)
-      if (nugget != 0) {
-        results$data <- results$data + matrix(rnorm((n * nsim), sd = sqrt(nugget)), 
-                                              ncol = nsim)
-      }
-    }
-    else{
-      results$data <- matrix(rnorm((n * nsim)), nrow = n, ncol = nsim)
-      cov.decomp <- t(varcov.spatial(coords = results$coords, 
-                                   cov.model = cov.model, kappa = kappa,
-                                   nugget = nugget, cov.pars = cov.pars, 
-                                   only.decomposition = TRUE,
-                                   func.inv = method)$sqrt.varcov)
-      results$data <- cov.decomp %*% results$data
-    }
-    if (nsim == 1) 
-      results$data <- as.vector(results$data)
-  }
-  ##
-  ## transforming data (Box - Cox)
-  ##
-  if (lambda != 1){
-    if (lambda != 0)
-      results$data <- (results$data * lambda + 1)^(1/lambda)
-    else
-      results$data <- exp(results$data)
-    messa$transformation <- paste("grf: Data transformed (Box-Cox), for lambda =", lambda)
-    if (messages.screen) 
-      cat(messa$transformation); cat("\n")
-  }
-  ##
-  ## back-transformation to the anisotropic space 
-  ##
-  if(!is.null(aniso.pars)) {
-    if(messages.screen)
-      cat("grf: back-transforming to the anisotropic space \n")
-    results$coords <- coords.aniso(coords = results$coords,
-                                   aniso.pars = aniso.pars, reverse=TRUE)
-  }
-  else{aniso.pars <- "no anisotropy parameters provided/used"}
-  ##
-  ## preparing output
-  ##
-  if (messages.screen) 
-    cat(paste("grf: End of simulation procedure. Number of realizations:",
-              nsim, "\n"))
-  results  <- c(results, list(cov.model = cov.model, 
-                              nugget = nugget, cov.pars = cov.pars,
-                              kappa = kappa, lambda = lambda,
-                              aniso.pars = aniso.pars, method = method,
-                              .Random.seed = rseed, messages = messa,
-                              call = call.fc))
-  class(results) <- c("grf", "geodata")
-  return(results)
-}
-
-"grf.aux1" <-
-  function (nst, nugget, sigmasq, phi, kappa, cov.model) 
-{
-  cov.nst <- paste("grf: process with ", nst, " covariance structure(s)\n")
-  cov.nugget <- paste("grf: nugget effect is: tausq=", nugget,"\n")
-  cov.message <- NULL
-  for (i in 1:nst) {
-    if (phi[i] == 0) 
-      cov.message[i] <- paste("grf: covariance model", i, "is a pure nugget effect\n")
-    else {
-      if (cov.model == "matern" | cov.model == "powered.exponential" | 
-          cov.model == "cauchy" | cov.model == "gneiting-matern") 
-        cov.message[i] <- paste("grf: covariance model ", 
-                                i, " is: ", cov.model, "(sigmasq=", sigmasq[i], 
-                                ", phi=", phi[i], ", kappa = ", kappa, ")\n", sep = "")
-      else cov.message[i] <- paste("grf: covariance model ", 
-                                   i, " is: ", cov.model, "(sigmasq=", sigmasq[i], 
-                                   ", phi=", phi[i], ")\n", sep = "")
-    }
-  }
-  return(list(nst = cov.nst, nugget = cov.nugget, cov.structures = cov.message))
-}
-"grf.aux2" <-
-  function (xlim, ylim, step, cov.model, phi, kappa = 0.5) 
-{
-  if(!is.null(kappa))
-    if (cov.model == "matern" & kappa == 0.5) {
-      cov.model <- "exponential"
-    }
-  cs <- switch(cov.model,
-               spherical = c(1,1),
-               gneiting.matern = c(2, kappa),
-               powered.exponential = c(3,kappa),
-               exponential = c(3,1),
-               gaussian = c(3,2),
-               matern = c(4, kappa),
-               gneiting = c(5,1),
-               cauchy = c(6,kappa),
-               wave = c(7,1))
-  covfct <- cs[1]
-  shape <- cs[2]
-  parameter <- c(phi, shape, 1)
-  nx <- c(diff(xlim)/step + 1, diff(ylim)/step + 1)
-  storage.mode(nx) <- "integer"
-  ln <- 2
-  storage.mode(ln) <- "integer"
-  covnr <- covfct
-  storage.mode(covnr) <- "integer"
-  simustep <- step
-  storage.mode(simustep) <- "double"
-  param <- parameter
-  storage.mode(param) <- "double"
-  lparam <- length(parameter)
-  storage.mode(lparam) <- "integer"
-  res <- double(nx[1] * nx[2])
-  mm <- integer(ln)
-  x <- .C("woodandchan", covnr, nx, ln, simustep, param, lparam, 
-          res = res, m = mm)$res
-  cat("\n")
-  return(x)
+  if(is.list(borders))
+    borders <- matrix(unlist(borders[1:2], ncol=2))
+  borders <- as.matrix(borders)
+  if(ncol(borders) != 2)
+    stop("borders must be a matrix or data-frame with two columns")
+  if (require(splancs) == F)
+    cat("package splancs in required to select points inside the borders\n")
+  locations <- locations[as.vector(inout(pts = locations,
+                                         poly = borders)),]
+  return(locations)
 }
 
 
@@ -307,8 +90,7 @@
   return(results)
 }
 
-"loglik.spatial" <-
-function(pars)
+"loglik.spatial" <- function(pars)
 {
   tausq <- pars[1]
   sigmasq <- pars[2]
@@ -407,16 +189,13 @@ function(pars)
 {
   if(is.vector(u)) names(u) <- NULL
   if(is.matrix(u)) dimnames(u) <- list(NULL, NULL)
-  uvec <- u/phi
-  ucov <- ifelse(uvec > 0, ((((2^(kappa-1))*gamma(kappa))^(-1))*(uvec^kappa)*besselK(x=uvec, nu=kappa)), 1)    
-  ## The following needs more checking:
-  ##        min.non.inf <- min(ucov[ucov != Inf])
-  ##        dist.min.non.inf <- min(u[ucov <= 1.01 * min.non.inf])
-  ##        ucov[u <= dist.min.non.inf] <- 0
-  ##        print(c(phi, dist.min.non.inf, min.non.inf))        
-  ##
-  ucov[u > 600*phi] <- 0 
-  return(ucov)
+  uphi <- u/phi
+  uphi <- ifelse(u > 0,
+                 (((2^(-(kappa-1)))/gamma(kappa)) *
+                  (uphi^kappa) *
+                  besselK(x=uphi, nu=kappa)), 1)    
+  uphi[u > 600*phi] <- 0 
+  return(uphi)
 }
 
 
@@ -532,7 +311,7 @@ function(pars)
 }
 
 "points.geodata" <-
-  function (geodata, coords = geodata$coords, data = geodata$data, 
+  function (x, coords = x$coords, data = x$data, 
             data.col = 1, borders = NULL,
             pt.sizes = c("data.proportional",
               "rank.proportional", "quintiles",
@@ -554,11 +333,8 @@ function(pars)
   ##
   ## data transformation (Box-Cox)
   ##
-  if (lambda != 1) {
-    if (lambda == 0) 
-      data <- log(data)
-    else data <- ((data^lambda) - 1)/lambda
-  }
+  if (lambda != 1)
+    data <- BCtransform.data(data, lambda)$data
   ##
   ## trend removal
   ##
@@ -577,8 +353,8 @@ function(pars)
       coords.lims <- set.coords.lims(coords=rbind(coords, borders))
     }
     par(pty = "s")
-    plot(apply(coords, 2, range), type = "n", xlim = coords.lims[, 
-                                                1], ylim = coords.lims[, 2], ...)
+    plot(apply(coords, 2, range), type = "n",
+         xlim = coords.lims[,1], ylim = coords.lims[, 2], ...)
     if(!is.null(borders))
       polygon(borders)
   }
@@ -677,3 +453,30 @@ function(pars)
   else return(invisible())
 }
 
+"dinvchisq" <-
+  function(x, df, scale=1/df, log = FALSE)
+{
+  if(df <= 0)
+    stop("df must be greater than zero")
+  if(scale <= 0)
+    stop("scale must be greater than zero")
+  nu <- df/2
+  if(log)
+    return(ifelse(x > 0, nu*log(nu) - log(gamma(nu)) + nu*log(scale) -
+                  (nu+1)*log(x) - (nu*scale/x), NA))
+  else
+    return(ifelse(x > 0,
+                  (((nu)^(nu))/gamma(nu)) * (scale^nu) *
+                  (x^(-(nu+1))) * exp(-nu*scale/x), NA))
+}
+
+"rinvchisq" <- 
+  function (n, df, scale = 1/df)
+{
+  if(df <= 0)
+    stop("df must be greater than zero")
+  if(scale <= 0)
+    stop("scale must be greater than zero")
+  return((df*scale)/rchisq(n, df=df)) 
+}
+
